Module: Kernel

Defined in:
lib/smartest/dsl.rb

Instance Method Summary collapse

Instance Method Details

#around_suite {|suite| ... } ⇒ void

This method returns an undefined value.

Register a hook that wraps the whole suite.

The block receives a ‘Smartest::SuiteRun` object and must call `suite.run` exactly once.

Yield Parameters:



# File 'lib/smartest/dsl.rb', line 52

#around_test {|test| ... } ⇒ void

This method returns an undefined value.

Register a hook that wraps tests declared after this hook in the same file.

The block receives a ‘Smartest::TestRun` object and must call `test.run` exactly once. The hook wraps fixture setup, the test body, and fixture teardown.

Yield Parameters:



# File 'lib/smartest/dsl.rb', line 52